"print.gstatVariogram" <-
function(x, ...)
{
	print(data.frame(x), ...)
}
